Module request

Module request 

Matchers that extract information from HTTP requests.

Structs

Body
The Body mapper returned by body()
Headers
The Headers mapper returned by headers()
Method
The Method mapper returned by method()
MethodPath
The MethodPath mapper returned by method_path()
Path
The Path mapper returned by path()
Query
The Query mapper returned by query()

Functions

body
Extract the body from the HTTP request and pass it to the next mapper.
headers
Extract the headers from the HTTP request and pass the sequence to the next mapper.
method
Extract the method from the HTTP request and pass it to the next mapper.
method_path
A convenience matcher for both method and path. Extracts a bolean true if the method and path both match.
path
Extract the path from the HTTP request and pass it to the next mapper.
query
Extract the query from the HTTP request and pass it to the next mapper.