Matchers that extract information from HTTP requests.
Structs
- Body
- The
Bodymapper returned by body() - Headers
- The
Headersmapper returned by headers() - Method
- The
Methodmapper returned by method() - Method
Path - The
MethodPathmapper returned by method_path() - Path
- The
Pathmapper returned by path() - Query
- The
Querymapper returned by query()
Functions
- body
- Extract the body from the HTTP request and pass it to the next mapper.
- headers
- Extract the headers from the HTTP request and pass the sequence to the next mapper.
- method
- Extract the method from the HTTP request and pass it to the next mapper.
- method_
path - A convenience matcher for both method and path. Extracts a bolean true if the method and path both match.
- path
- Extract the path from the HTTP request and pass it to the next mapper.
- query
- Extract the query from the HTTP request and pass it to the next mapper.